@@ -43,69 +43,117 @@ except ImportError:
     import pathlib2 as pathlib
 
 
-SETTINGS_MODULE_ENV = 'DJANGO_SETTINGS_MODULE'
-CONFIGURATION_ENV = 'DJANGO_CONFIGURATION'
-INVALID_TEMPLATE_VARS_ENV = 'FAIL_INVALID_TEMPLATE_VARS'
+SETTINGS_MODULE_ENV = "DJANGO_SETTINGS_MODULE"
+CONFIGURATION_ENV = "DJANGO_CONFIGURATION"
+INVALID_TEMPLATE_VARS_ENV = "FAIL_INVALID_TEMPLATE_VARS"
 
 PY2 = sys.version_info[0] == 2
 
 
 # ############### pytest hooks ################
 
+
 def pytest_addoption(parser):
-    group = parser.getgroup('django')
-    group._addoption('--reuse-db',
-                     action='store_true', dest='reuse_db', default=False,
-                     help='Re-use the testing database if it already exists, '
-                          'and do not remove it when the test finishes.')
-    group._addoption('--create-db',
-                     action='store_true', dest='create_db', default=False,
-                     help='Re-create the database, even if it exists. This '
-                          'option can be used to override --reuse-db.')
-    group._addoption('--ds',
-                     action='store', type=str, dest='ds', default=None,
-                     help='Set DJANGO_SETTINGS_MODULE.')
-    group._addoption('--dc',
-                     action='store', type=str, dest='dc', default=None,
-                     help='Set DJANGO_CONFIGURATION.')
-    group._addoption('--nomigrations', '--no-migrations',
-                     action='store_true', dest='nomigrations', default=False,
-                     help='Disable Django migrations on test setup')
-    group._addoption('--migrations',
-                     action='store_false', dest='nomigrations', default=False,
-                     help='Enable Django migrations on test setup')
-    parser.addini(CONFIGURATION_ENV,
-                  'django-configurations class to use by pytest-django.')
-    group._addoption('--liveserver', default=None,
-                     help='Address and port for the live_server fixture.')
-    parser.addini(SETTINGS_MODULE_ENV,
-                  'Django settings module to use by pytest-django.')
+    group = parser.getgroup("django")
+    group._addoption(
+        "--reuse-db",
+        action="store_true",
+        dest="reuse_db",
+        default=False,
+        help="Re-use the testing database if it already exists, "
+        "and do not remove it when the test finishes.",
+    )
+    group._addoption(
+        "--create-db",
+        action="store_true",
+        dest="create_db",
+        default=False,
+        help="Re-create the database, even if it exists. This "
+        "option can be used to override --reuse-db.",
+    )
+    group._addoption(
+        "--ds",
+        action="store",
+        type=str,
+        dest="ds",
+        default=None,
+        help="Set DJANGO_SETTINGS_MODULE.",
+    )
+    group._addoption(
+        "--dc",
+        action="store",
+        type=str,
+        dest="dc",
+        default=None,
+        help="Set DJANGO_CONFIGURATION.",
+    )
+    group._addoption(
+        "--nomigrations",
+        "--no-migrations",
+        action="store_true",
+        dest="nomigrations",
+        default=False,
+        help="Disable Django migrations on test setup",
+    )
+    group._addoption(
+        "--migrations",
+        action="store_false",
+        dest="nomigrations",
+        default=False,
+        help="Enable Django migrations on test setup",
+    )
+    parser.addini(
+        CONFIGURATION_ENV, "django-configurations class to use by pytest-django."
+    )
+    group._addoption(
+        "--liveserver",
+        default=None,
+        help="Address and port for the live_server fixture.",
+    )
+    parser.addini(
+        SETTINGS_MODULE_ENV, "Django settings module to use by pytest-django."
+    )
 
-    parser.addini('django_find_project',
-                  'Automatically find and add a Django project to the '
-                  'Python path.',
-                  type='bool', default=True)
-    group._addoption('--fail-on-template-vars',
-                     action='store_true', dest='itv', default=False,
-                     help='Fail for invalid variables in templates.')
-    parser.addini(INVALID_TEMPLATE_VARS_ENV,
-                  'Fail for invalid variables in templates.',
-                  type='bool', default=False)
+    parser.addini(
+        "django_find_project",
+        "Automatically find and add a Django project to the " "Python path.",
+        type="bool",
+        default=True,
+    )
+    group._addoption(
+        "--fail-on-template-vars",
+        action="store_true",
+        dest="itv",
+        default=False,
+        help="Fail for invalid variables in templates.",
+    )
+    parser.addini(
+        INVALID_TEMPLATE_VARS_ENV,
+        "Fail for invalid variables in templates.",
+        type="bool",
+        default=False,
+    )
 
 
-PROJECT_FOUND = ('pytest-django found a Django project in %s '
-                 '(it contains manage.py) and added it to the Python path.\n'
-                 'If this is wrong, add "django_find_project = false" to '
-                 'pytest.ini and explicitly manage your Python path.')
+PROJECT_FOUND = (
+    "pytest-django found a Django project in %s "
+    "(it contains manage.py) and added it to the Python path.\n"
+    'If this is wrong, add "django_find_project = false" to '
+    "pytest.ini and explicitly manage your Python path."
+)
 
-PROJECT_NOT_FOUND = ('pytest-django could not find a Django project '
-                     '(no manage.py file could be found). You must '
-                     'explicitly add your Django project to the Python path '
-                     'to have it picked up.')
+PROJECT_NOT_FOUND = (
+    "pytest-django could not find a Django project "
+    "(no manage.py file could be found). You must "
+    "explicitly add your Django project to the Python path "
+    "to have it picked up."
+)
 
-PROJECT_SCAN_DISABLED = ('pytest-django did not search for Django '
-                         'projects since it is disabled in the configuration '
-                         '("django_find_project = false")')
+PROJECT_SCAN_DISABLED = (
+    "pytest-django did not search for Django "
+    "projects since it is disabled in the configuration "
+    '("django_find_project = false")'
+)
 
 
 @contextlib.contextmanager
@@ -113,14 +161,17 @@ def _handle_import_error(extra_message):
     try:
         yield
     except ImportError as e:
-        django_msg = (e.args[0] + '\n\n') if e.args else ''
+        django_msg = (e.args[0] + "\n\n") if e.args else ""
         msg = django_msg + extra_message
         raise ImportError(msg)
 
 
 def _add_django_project_to_path(args):
     def is_django_project(path):
-        return path.is_dir() and (path / 'manage.py').exists()
+        try:
+            return path.is_dir() and (path / "manage.py").exists()
+        except OSError:
+            return False
 
     def arg_to_path(arg):
         # Test classes or functions can be appended to paths separated by ::
@@ -130,7 +181,6 @@ def _add_django_project_to_path(args):
     def find_django_path(args):
         args = map(str, args)
         args = [arg_to_path(x) for x in args if not x.startswith("-")]
-        args = [p for p in args if p.is_dir()]
 
         if not args:
             args = [pathlib.Path.cwd()]
@@ -151,7 +201,7 @@ def _add_django_project_to_path(args):
 
 
 def _setup_django():
-    if 'django' not in sys.modules:
+    if "django" not in sys.modules:
         return
 
     import django.conf
@@ -161,6 +211,7 @@ def _setup_django():
         return
 
     import django.apps
+
     if not django.apps.apps.ready:
         django.setup()
 
@@ -172,36 +223,37 @@ def _get_boolean_value(x, name, default=None):
         return default
     if x in (True, False):
         return x
-    possible_values = {'true': True,
-                       'false': False,
-                       '1': True,
-                       '0': False}
+    possible_values = {"true": True, "false": False, "1": True, "0": False}
     try:
         return possible_values[x.lower()]
     except KeyError:
-        raise ValueError('{} is not a valid value for {}. '
-                         'It must be one of {}.'
-                         % (x, name, ', '.join(possible_values.keys())))
+        raise ValueError(
+            "{} is not a valid value for {}. "
+            "It must be one of {}." % (x, name, ", ".join(possible_values.keys()))
+        )
 
 
 def pytest_load_initial_conftests(early_config, parser, args):
     # Register the marks
     early_config.addinivalue_line(
-        'markers',
-        'django_db(transaction=False): Mark the test as using '
-        'the django test database.  The *transaction* argument marks will '
+        "markers",
+        "django_db(transaction=False): Mark the test as using "
+        "the django test database.  The *transaction* argument marks will "
         "allow you to use real transactions in the test like Django's "
-        'TransactionTestCase.')
+        "TransactionTestCase.",
+    )
     early_config.addinivalue_line(
-        'markers',
-        'urls(modstr): Use a different URLconf for this test, similar to '
-        'the `urls` attribute of Django `TestCase` objects.  *modstr* is '
-        'a string specifying the module of a URL config, e.g. '
-        '"my_app.test_urls".')
+        "markers",
+        "urls(modstr): Use a different URLconf for this test, similar to "
+        "the `urls` attribute of Django `TestCase` objects.  *modstr* is "
+        "a string specifying the module of a URL config, e.g. "
+        '"my_app.test_urls".',
+    )
     early_config.addinivalue_line(
-        'markers',
-        'ignore_template_errors(): ignore errors from invalid template '
-        'variables (if --fail-on-template-vars is used).')
+        "markers",
+        "ignore_template_errors(): ignore errors from invalid template "
+        "variables (if --fail-on-template-vars is used).",
+    )
 
     options = parser.parse_known_args(args)
 
@@ -209,43 +261,51 @@ def pytest_load_initial_conftests(early_config, parser, args):
         return
 
     django_find_project = _get_boolean_value(
-        early_config.getini('django_find_project'), 'django_find_project')
+        early_config.getini("django_find_project"), "django_find_project"
+    )
 
     if django_find_project:
         _django_project_scan_outcome = _add_django_project_to_path(args)
     else:
         _django_project_scan_outcome = PROJECT_SCAN_DISABLED
 
-    if (options.itv or
-            _get_boolean_value(os.environ.get(INVALID_TEMPLATE_VARS_ENV),
-                               INVALID_TEMPLATE_VARS_ENV) or
-            early_config.getini(INVALID_TEMPLATE_VARS_ENV)):
-        os.environ[INVALID_TEMPLATE_VARS_ENV] = 'true'
+    if (
+        options.itv
+        or _get_boolean_value(
+            os.environ.get(INVALID_TEMPLATE_VARS_ENV), INVALID_TEMPLATE_VARS_ENV
+        )
+        or early_config.getini(INVALID_TEMPLATE_VARS_ENV)
+    ):
+        os.environ[INVALID_TEMPLATE_VARS_ENV] = "true"
 
     # Configure DJANGO_SETTINGS_MODULE
     if options.ds:
-        ds_source = 'command line option'
+        ds_source = "command line option"
         ds = options.ds
     elif SETTINGS_MODULE_ENV in os.environ:
         ds = os.environ[SETTINGS_MODULE_ENV]
-        ds_source = 'environment variable'
+        ds_source = "environment variable"
     elif early_config.getini(SETTINGS_MODULE_ENV):
         ds = early_config.getini(SETTINGS_MODULE_ENV)
-        ds_source = 'ini file'
+        ds_source = "ini file"
     else:
         ds = None
         ds_source = None
 
     if ds:
-        early_config._dsm_report_header = 'Django settings: %s (from %s)' % (
-            ds, ds_source)
+        early_config._dsm_report_header = "Django settings: %s (from %s)" % (
+            ds,
+            ds_source,
+        )
     else:
         early_config._dsm_report_header = None
 
     # Configure DJANGO_CONFIGURATION
-    dc = (options.dc or
-          os.environ.get(CONFIGURATION_ENV) or
-          early_config.getini(CONFIGURATION_ENV))
+    dc = (
+        options.dc
+        or os.environ.get(CONFIGURATION_ENV)
+        or early_config.getini(CONFIGURATION_ENV)
+    )
 
     if ds:
         os.environ[SETTINGS_MODULE_ENV] = ds
@@ -255,6 +315,7 @@ def pytest_load_initial_conftests(early_config, parser, args):
 
             # Install the django-configurations importer
             import configurations.importer
+
             configurations.importer.install()
 
         # Forcefully load Django settings, throws ImportError or
@@ -288,18 +349,21 @@ def _classmethod_is_defined_at_leaf(cls, method_name):
             break
 
     assert super_method is not None, (
-        '%s could not be found in base classes' % method_name)
+        "%s could not be found in base classes" % method_name
+    )
 
     method = getattr(cls, method_name)
 
     try:
         f = method.__func__
     except AttributeError:
-        pytest.fail('%s.%s should be a classmethod' % (cls, method_name))
-    if PY2 and not (inspect.ismethod(method) and
-                    inspect.isclass(method.__self__) and
-                    issubclass(cls, method.__self__)):
-        pytest.fail('%s.%s should be a classmethod' % (cls, method_name))
+        pytest.fail("%s.%s should be a classmethod" % (cls, method_name))
+    if PY2 and not (
+        inspect.ismethod(method)
+        and inspect.isclass(method.__self__)
+        and issubclass(cls, method.__self__)
+    ):
+        pytest.fail("%s.%s should be a classmethod" % (cls, method_name))
     return f is not super_method.__func__
 
 
@@ -313,10 +377,10 @@ def _disable_class_methods(cls):
     _disabled_classmethods[cls] = (
         # Get the classmethod object (not the resulting bound method),
         # otherwise inheritance will be broken when restoring.
-        cls.__dict__.get('setUpClass'),
-        _classmethod_is_defined_at_leaf(cls, 'setUpClass'),
-        cls.__dict__.get('tearDownClass'),
-        _classmethod_is_defined_at_leaf(cls, 'tearDownClass'),
+        cls.__dict__.get("setUpClass"),
+        _classmethod_is_defined_at_leaf(cls, "setUpClass"),
+        cls.__dict__.get("tearDownClass"),
+        _classmethod_is_defined_at_leaf(cls, "tearDownClass"),
     )
 
     cls.setUpClass = types.MethodType(lambda cls: None, cls)
@@ -324,10 +388,12 @@ def _disable_class_methods(cls):
 
 
 def _restore_class_methods(cls):
-    (setUpClass,
-     restore_setUpClass,
-     tearDownClass,
-     restore_tearDownClass) = _disabled_classmethods.pop(cls)
+    (
+        setUpClass,
+        restore_setUpClass,
+        tearDownClass,
+        restore_tearDownClass,
+    ) = _disabled_classmethods.pop(cls)
 
     try:
         del cls.setUpClass
@@ -352,7 +418,7 @@ def pytest_runtest_setup(item):
         _disable_class_methods(cls)
 
 
-@pytest.fixture(autouse=True, scope='session')
+@pytest.fixture(autouse=True, scope="session")
 def django_test_environment(request):
     """
     Ensure that Django is loaded and has its testing environment setup.
@@ -367,14 +433,14 @@ def django_test_environment(request):
     if django_settings_is_configured():
         _setup_django()
         from django.conf import settings as dj_settings
-        from django.test.utils import (setup_test_environment,
-                                       teardown_test_environment)
+        from django.test.utils import setup_test_environment, teardown_test_environment
+
         dj_settings.DEBUG = False
         setup_test_environment()
         request.addfinalizer(teardown_test_environment)
 
 
-@pytest.fixture(scope='session')
+@pytest.fixture(scope="session")
 def django_db_blocker():
     """Wrapper around Django's database access.
 
@@ -401,23 +467,23 @@ def _django_db_marker(request):
     This will dynamically request the ``db``, ``transactional_db`` or
     ``django_db_reset_sequences`` fixtures as required by the django_db marker.
     """
-    marker = request.node.get_closest_marker('django_db')
+    marker = request.node.get_closest_marker("django_db")
     if marker:
         transaction, reset_sequences = validate_django_db(marker)
         if reset_sequences:
-            request.getfixturevalue('django_db_reset_sequences')
+            request.getfixturevalue("django_db_reset_sequences")
         elif transaction:
-            request.getfixturevalue('transactional_db')
+            request.getfixturevalue("transactional_db")
         else:
-            request.getfixturevalue('db')
+            request.getfixturevalue("db")
 
 
-@pytest.fixture(autouse=True, scope='class')
+@pytest.fixture(autouse=True, scope="class")
 def _django_setup_unittest(request, django_db_blocker):
     """Setup a django unittest, internal to pytest-django."""
     if django_settings_is_configured() and is_django_unittest(request):
-        request.getfixturevalue('django_test_environment')
-        request.getfixturevalue('django_db_setup')
+        request.getfixturevalue("django_test_environment")
+        request.getfixturevalue("django_db_setup")
 
         django_db_blocker.unblock()
 
@@ -427,9 +493,9 @@ def _django_setup_unittest(request, django_db_blocker):
         # see pytest-dev/pytest-django#406
         def _cleaning_debug(self):
             testMethod = getattr(self, self._testMethodName)
-            skipped = (
-                getattr(self.__class__, "__unittest_skip__", False) or
-                getattr(testMethod, "__unittest_skip__", False))
+            skipped = getattr(self.__class__, "__unittest_skip__", False) or getattr(
+                testMethod, "__unittest_skip__", False
+            )
 
             if not skipped:
                 self._pre_setup()
@@ -451,42 +517,46 @@ def _django_setup_unittest(request, django_db_blocker):
         request.addfinalizer(teardown)
 
 
-@pytest.fixture(scope='function', autouse=True)
+@pytest.fixture(scope="function", autouse=True)
 def _dj_autoclear_mailbox():
     if not django_settings_is_configured():
         return
 
     from django.core import mail
+
     del mail.outbox[:]
 
 
-@pytest.fixture(scope='function')
+@pytest.fixture(scope="function")
 def mailoutbox(monkeypatch, django_mail_patch_dns, _dj_autoclear_mailbox):
     if not django_settings_is_configured():
         return
 
     from django.core import mail
+
     return mail.outbox
 
 
-@pytest.fixture(scope='function')
+@pytest.fixture(scope="function")
 def django_mail_patch_dns(monkeypatch, django_mail_dnsname):
     from django.core import mail
-    monkeypatch.setattr(mail.message, 'DNS_NAME', django_mail_dnsname)
+
+    monkeypatch.setattr(mail.message, "DNS_NAME", django_mail_dnsname)
 
 
-@pytest.fixture(scope='function')
+@pytest.fixture(scope="function")
 def django_mail_dnsname(monkeypatch):
-    return 'fake-tests.example.com'
+    return "fake-tests.example.com"
 
 
-@pytest.fixture(autouse=True, scope='function')
+@pytest.fixture(autouse=True, scope="function")
 def _django_set_urlconf(request):
     """Apply the @pytest.mark.urls marker, internal to pytest-django."""
-    marker = request.node.get_closest_marker('urls')
+    marker = request.node.get_closest_marker("urls")
     if marker:
         skip_if_no_django()
         import django.conf
+
         try:
             from django.urls import clear_url_caches, set_urlconf
         except ImportError:
@@ -509,7 +579,7 @@ def _django_set_urlconf(request):
         request.addfinalizer(restore)
 
 
-@pytest.fixture(autouse=True, scope='session')
+@pytest.fixture(autouse=True, scope="session")
 def _fail_for_invalid_template_variable(request):
     """Fixture that fails for invalid variables in templates.
 
@@ -523,6 +593,7 @@ def _fail_for_invalid_template_variable(request):
     This behavior can be switched off using the marker:
     ``pytest.mark.ignore_template_errors``
     """
+
     class InvalidVarException(object):
         """Custom handler for invalid strings in templates."""
 
@@ -531,7 +602,7 @@ def _fail_for_invalid_template_variable(request):
 
         def __contains__(self, key):
             """There is a test for '%s' in TEMPLATE_STRING_IF_INVALID."""
-            return key == '%s'
+            return key == "%s"
 
         @staticmethod
         def _get_origin():
@@ -541,10 +612,10 @@ def _fail_for_invalid_template_variable(request):
             # TEMPLATE_DEBUG)..
             for f in stack[2:]:
                 func = f[3]
-                if func == 'render':
+                if func == "render":
                     frame = f[0]
                     try:
-                        origin = frame.f_locals['self'].origin
+                        origin = frame.f_locals["self"].origin
                     except (AttributeError, KeyError):
                         continue
                     if origin is not None:
@@ -554,18 +625,16 @@ def _fail_for_invalid_template_variable(request):
 
             # finding the ``render`` needle in the stack
             frame = reduce(
-                lambda x, y: y[3] == 'render' and 'base.py' in y[1] and y or x,
-                stack
+                lambda x, y: y[3] == "render" and "base.py" in y[1] and y or x, stack
             )
             # assert 0, stack
             frame = frame[0]
             # finding only the frame locals in all frame members
             f_locals = reduce(
-                lambda x, y: y[0] == 'f_locals' and y or x,
-                inspect.getmembers(frame)
+                lambda x, y: y[0] == "f_locals" and y or x, inspect.getmembers(frame)
             )[1]
             # ``django.template.base.Template``
-            template = f_locals['self']
+            template = f_locals["self"]
             if isinstance(template, Template):
                 return template.name
 
@@ -573,8 +642,7 @@ def _fail_for_invalid_template_variable(request):
             """Handle TEMPLATE_STRING_IF_INVALID % var."""
             origin = self._get_origin()
             if origin:
-                msg = "Undefined template variable '%s' in '%s'" % (
-                    var, origin)
+                msg = "Undefined template variable '%s' in '%s'" % (var, origin)
             else:
                 msg = "Undefined template variable '%s'" % var
             if self.fail:
@@ -582,13 +650,16 @@ def _fail_for_invalid_template_variable(request):
             else:
                 return msg
 
-    if (os.environ.get(INVALID_TEMPLATE_VARS_ENV, 'false') == 'true' and
-            django_settings_is_configured()):
+    if (
+        os.environ.get(INVALID_TEMPLATE_VARS_ENV, "false") == "true"
+        and django_settings_is_configured()
+    ):
         from django.conf import settings as dj_settings
 
         if dj_settings.TEMPLATES:
-            dj_settings.TEMPLATES[0]['OPTIONS']['string_if_invalid'] = (
-                InvalidVarException())
+            dj_settings.TEMPLATES[0]["OPTIONS"][
+                "string_if_invalid"
+            ] = InvalidVarException()
         else:
             dj_settings.TEMPLATE_STRING_IF_INVALID = InvalidVarException()
 
@@ -597,18 +668,18 @@ def _fail_for_invalid_template_variable(request):
 def _template_string_if_invalid_marker(request):
     """Apply the @pytest.mark.ignore_template_errors marker,
      internal to pytest-django."""
-    marker = request.keywords.get('ignore_template_errors', None)
-    if os.environ.get(INVALID_TEMPLATE_VARS_ENV, 'false') == 'true':
+    marker = request.keywords.get("ignore_template_errors", None)
+    if os.environ.get(INVALID_TEMPLATE_VARS_ENV, "false") == "true":
         if marker and django_settings_is_configured():
             from django.conf import settings as dj_settings
 
             if dj_settings.TEMPLATES:
-                dj_settings.TEMPLATES[0]['OPTIONS']['string_if_invalid'].fail = False
+                dj_settings.TEMPLATES[0]["OPTIONS"]["string_if_invalid"].fail = False
             else:
                 dj_settings.TEMPLATE_STRING_IF_INVALID.fail = False
 
 
-@pytest.fixture(autouse=True, scope='function')
+@pytest.fixture(autouse=True, scope="function")
 def _django_clear_site_cache():
     """Clears ``django.contrib.sites.models.SITE_CACHE`` to avoid
     unexpected behavior with cached site objects.
@@ -617,10 +688,12 @@ def _django_clear_site_cache():
     if django_settings_is_configured():
         from django.conf import settings as dj_settings
 
-        if 'django.contrib.sites' in dj_settings.INSTALLED_APPS:
+        if "django.contrib.sites" in dj_settings.INSTALLED_APPS:
             from django.contrib.sites.models import Site
+
             Site.objects.clear_cache()
 
+
 # ############### Helper Functions ################
 
 
@@ -662,9 +735,11 @@ class _DatabaseBlocker(object):
     def _blocking_wrapper(*args, **kwargs):
         __tracebackhide__ = True
         __tracebackhide__  # Silence pyflakes
-        pytest.fail('Database access not allowed, '
-                    'use the "django_db" mark, or the '
-                    '"db" or "transactional_db" fixtures to enable it.')
+        pytest.fail(
+            "Database access not allowed, "
+            'use the "django_db" mark, or the '
+            '"db" or "transactional_db" fixtures to enable it.'
+        )
 
     def unblock(self):
         """Enable access to the Django database."""
@@ -694,8 +769,10 @@ def validate_django_db(marker):
 
     A sequence reset is only allowed when combined with a transaction.
     """
+
     def apifun(transaction=False, reset_sequences=False):
         return transaction, reset_sequences
+
     return apifun(*marker.args, **marker.kwargs)
 
 
@@ -705,6 +782,8 @@ def validate_urls(marker):
     It checks the signature and creates the `urls` attribute on the
     marker which will have the correct value.
     """
+
     def apifun(urls):
         return urls
+
     return apifun(*marker.args, **marker.kwargs)
